diff --git a/assignments/src/MV3500Cohort2021JulySeptember/projects/Fisher/MV3500ProjectFisher.java b/assignments/src/MV3500Cohort2021JulySeptember/projects/Fisher/MV3500ProjectFisher.java
index 1084c12dd4df339e05f766d41c81f1b8e5e311eb..27bfb1f8080228dbe09dfe3221294c520697226f 100644
--- a/assignments/src/MV3500Cohort2021JulySeptember/projects/Fisher/MV3500ProjectFisher.java
+++ b/assignments/src/MV3500Cohort2021JulySeptember/projects/Fisher/MV3500ProjectFisher.java
@@ -10,8 +10,9 @@
  */
 package MV3500Cohort2021JulySeptember.projects.Fisher;
 
-import edu.nps.moves.dis7.entities.afg.lifeform.land.CivilianAdultMalewCellPhone;
-import edu.nps.moves.dis7.entities.usa.lifeform.land.*;
+//import edu.nps.moves.dis7.entities.afg.lifeform.land.CivilianAdultMalewCellPhone;
+//import edu.nps.moves.dis7.entities.usa.lifeform.land.*;
+import edu.nps.moves.dis7.entities.afg.platform.land.PoliceCar;
 import edu.nps.moves.dis7.entities.usa.platform.land.M1281CloseCombatWeaponsCarrierJLTVCCWC;
 import edu.nps.moves.dis7.enumerations.*; // match any
 import edu.nps.moves.dis7.pdus.*;         // match any of the PDU classes, easier than listing individually
@@ -80,7 +81,7 @@ public class MV3500ProjectFisher
         entityStatePdu_1.setEntityID(entityID_1);
         entityStatePdu_1.getEntityLocation().setX(0).setY(0).setZ(0);
         entityStatePdu_1.setForceId(ForceID.FRIENDLY);
-        entityStatePdu_1.setAlternativeEntityType(new _762x51mmM240E4M240BGPMG() );
+//      entityStatePdu_1.setAlternativeEntityType(new _762x51mmM240E4M240BGPMG() ); // obsolete 
 
 //          Again, example of the not so good way to do things        
 //        EntityType entityType_2 = new EntityType();
@@ -91,11 +92,12 @@ public class MV3500ProjectFisher
 //        entityType_2.setSubCategory(1);                                 // cell phone
 
 
         // Entity 2 is an enemy Afghan male with cell phone.
         EntityID       entityID_2    = new EntityID();
         entityID_2.setEntityID(2);
         EntityStatePdu entityStatePdu_2 = pduFactory.makeEntityStatePdu();
-        entityStatePdu_2.setEntityType(new CivilianAdultMalewCellPhone());
+//      entityStatePdu_2.setEntityType(new CivilianAdultMalewCellPhone());
+        entityStatePdu_2.setEntityType(new PoliceCar());
         entityStatePdu_2.setEntityID(entityID_2);
         entityStatePdu_2.getEntityLocation().setX(10).setY(0).setZ(100);
         entityStatePdu_2.setForceId(ForceID.OPPOSING);
@@ -91,11 +92,12 @@ public class MV3500ProjectFisher
 
 
-        // Entity 2 is an enemy Afghan male with cell phone.
+        // Entity 2 is an enemy Afghan male with cell phone.,, now obsolete, use PoliceCar instead
         EntityID       entityID_2    = new EntityID();
         entityID_2.setEntityID(2);